@@ -13,7 +13,7 @@ import re
 import sys
 
 from coverage import env
-from coverage.exceptions import CoverageException
+from coverage.exceptions import ConfigError
 from coverage.misc import contract, human_sorted, isolate_module, join_regex
 
 
@@ -137,21 +137,15 @@ if env.WINDOWS:
         return actpath
 
 else:
-    def actual_path(filename):
+    def actual_path(path):
         """The actual path for non-Windows platforms."""
-        return filename
+        return path
 
 
 @contract(returns='unicode')
 def abs_file(path):
     """Return the absolute normalized form of `path`."""
-    try:
-        path = os.path.realpath(path)
-    except UnicodeError:
-        pass
-    path = os.path.abspath(path)
-    path = actual_path(path)
-    return path
+    return actual_path(os.path.abspath(os.path.realpath(path)))
 
 
 def python_reported_file(filename):
@@ -276,7 +270,7 @@ def sep(s):
     """Find the path separator used in this string, or os.sep if none."""
     sep_match = re.search(r"[\\/]", s)
     if sep_match:
-        the_sep = sep_match.group(0)
+        the_sep = sep_match[0]
     else:
         the_sep = os.sep
     return the_sep
@@ -356,7 +350,7 @@ class PathAliases:
 
         # The pattern can't end with a wildcard component.
         if pattern.endswith("*"):
-            raise CoverageException("Pattern must not end with wildcards.")
+            raise ConfigError("Pattern must not end with wildcards.")
 
         # The pattern is meant to match a filepath.  Let's make it absolute
         # unless it already is, or is meant to match any prefix.
@@ -393,7 +387,7 @@ class PathAliases:
         for regex, result in self.aliases:
             m = regex.match(path)
             if m:
-                new = path.replace(m.group(0), result)
+                new = path.replace(m[0], result)
                 new = new.replace(sep(path), sep(result))
                 if not self.relative:
                     new = canonical_filename(new)
